@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Error;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Contains a single error from a JSON Schema evaluation
 
-our $VERSION = '0.627';
+our $VERSION = '0.628';
 
 use 5.020;
 use Moo;
@@ -24,6 +24,7 @@ use Types::Standard qw(Str Bool Enum Tuple);
 use Types::Common::Numeric qw(PositiveInt);
 use builtin::compat 'refaddr';
 use Mojo::Message::Response;
+use Carp 'croak';
 use namespace::clean;
 
 use overload
@@ -76,6 +77,9 @@ around BUILDARGS => sub ($orig, $class, @args) {
       Mojo::Message::Response->default_message($args->{recommended_response}[0]) // 'Unknown Error'
     if $args->{recommended_response} and $args->{recommended_response}->@* == 1;
 
+  croak 'instance_location must be defined when mode=evaluate'
+    if not defined $args->{instance_location} and ($args->{mode}//'') eq 'evaluate';
+
   return $args;
 };
 
@@ -95,7 +99,7 @@ JSON::Schema::Modern::Error - Contains a single error from a JSON Schema evaluat
 
 =head1 VERSION
 
-version 0.627
+version 0.628
 
 =head1 SYNOPSIS
 
